#!/bin/bash

/usr/local/bin/docker-entrypoint.sh "$@" &

echo "[DEBUG] Checking if MongoDB is already running and init setup is done."

MONGO_CMD="mongo --quiet --username $MONGO_INITDB_ROOT_USERNAME --password $MONGO_INITDB_ROOT_PASSWORD --authenticationDatabase $MONGO_INITDB_DATABASE"
tries=30
while true; do
  if ${MONGO_CMD} --eval 'quit(0)' &> /dev/null; then
    break
  fi
  (( tries-- ))
  if [ "$tries" -le 0 ]; then
    echo >&2
    echo >&2 "[ERROR] MongoDB did not accepted connections quickly enough. Replica set configuration failed."
    echo >&2
    exit 1
  fi
  echo "[DEBUG] Waiting for MongoDB to start running and accept connections."
  sleep 1
done

# check if replica set is already initiated
RS_STATUS=$( ${MONGO_CMD} --eval "rs.status().ok" )
if [[ $RS_STATUS -ne 1 ]]
then
  echo "[INFO] Replication set config invalid. Reconfiguring now."
  RS_CONFIG_STATUS=$( ${MONGO_CMD} --eval "rs.status().codeName" )
  if [[ $RS_CONFIG_STATUS == 'NotYetInitialized' ]]
  then
    echo "[INFO] Initiating standalone replica set."
    ${MONGO_CMD} --eval "rs.initiate()" > /dev/null
    echo "[INFO] MongoDB setup finished."
  elif [[ $RS_CONFIG_STATUS == 'InvalidReplicaSetConfig' ]]
  then
    echo "[INFO] Replica set configuration found is invalid. Trying to reconfigure member hostname for standalone replica set."
    ${MONGO_CMD} > /dev/null <<EOF
config = rs.config()
config.members[0].host = hostname()
rs.reconfig(config, {force: true})
EOF
    echo "[INFO] MongoDB setup finished."
  else
    echo "[ERROR] Found unexpected replica set status '$RS_CONFIG_STATUS'. Cannot initiate nor reconfigure standalone replica set"
  fi
else
  echo "[INFO] Replica set already initiated."
fi

wait