#!/bin/bash

set -e

# Wait for the file containing the client secret created by the keycloak init container to be created
dateLimit=$(date +%s)
dateLimit=$((dateLimit + 120)) # 120 seconds timeout
while [[ ! -f /shared/clientsecret && "$(date +%s)" < "${dateLimit}" ]]
do
    echo "Waiting for clientsecret to be retrieved from keycloak"
    sleep 2
done
[[ -f /shared/clientsecret ]] || {
      echo "Max attempt reached. Aborting..."
      return 1
} >&2

authPodName=`kubectl get pods -l 'app.kubernetes.io/instance=saagie-common,app.kubernetes.io/name=auth'  -o name --namespace $1 | sed 's/pods\///'`

clientSecret=`cat /shared/clientsecret`


echo "Updating secret in {{ .Values.global.customer.name }}-keycloak.json with value $clientSecret"
cat customer-keycloak.json | sed "s/##secret##/$clientSecret/" > /tmp/customer-keycloak.json

kubectl delete secret auth-secret-{{ .Values.global.customer.name }} --namespace $1 --ignore-not-found
kubectl create secret generic auth-secret-{{ .Values.global.customer.name }} --from-file=auth.json=customer-auth.json --from-file=keycloak.json=/tmp/customer-keycloak.json --from-file=customer.json=customer-config.json --from-literal=customer={{ .Values.global.customer.name }} --namespace $1
kubectl label secret auth-secret-{{ .Values.global.customer.name }} app=auth dynamicConfig=true io.saagie/installationId=$1 --namespace $1

rm /shared/clientsecret
