/*
 * Template for JavaScript based authenticator's.
 * See org.keycloak.authentication.authenticators.browser.ScriptBasedAuthenticatorFactory
 */

AuthenticationFlowError = Java.type("org.keycloak.authentication.AuthenticationFlowError");
ClientAuthUtil = Java.type("org.keycloak.authentication.authenticators.client.ClientAuthUtil");
Response = Java.type("javax.ws.rs.core.Response");

/**
 * An example authenticate function.
 *
 * The following variables are available for convenience:
 * user - current user {@see org.keycloak.models.UserModel}
 * realm - current realm {@see org.keycloak.models.RealmModel}
 * session - current KeycloakSession {@see org.keycloak.models.KeycloakSession}
 * httpRequest - current HttpRequest {@see org.jboss.resteasy.spi.HttpRequest}
 * script - current script {@see org.keycloak.models.ScriptModel}
 * clientSession - current client session {@see org.keycloak.models.ClientSessionModel}
 * LOG - current logger {@see org.jboss.logging.Logger}
 *
 * You one can extract current http request headers via:
 * httpRequest.getHttpHeaders().getHeaderString("Forwarded")
 *
 * @param context {@see org.keycloak.authentication.AuthenticationFlowContext}
 */
function authenticate(context) {
    if (user !== null && user.attributes !== null && user.attributes.freeipaExpiration !== null && user.attributes.freeipaExpiration.length > 0) {

        // Parse FreeIPA expiration date (format is 20170720130916Z)
        var regex = /(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})Z/;
        var dateArray = regex.exec(user.attributes.freeipaExpiration[0]);

        var freeipaExpirationDate = new Date(
            (+dateArray[1]),
            (+dateArray[2]) - 1, // Month starts at 0
            (+dateArray[3]),
            (+dateArray[4]),
            (+dateArray[5]),
            (+dateArray[6])
        );

        if(freeipaExpirationDate < Date.now()) {
            LOG.error("Fail to authenticate user " + user.username + ": account expired (" + freeipaExpirationDate + ")");
            var response = ClientAuthUtil.errorResponse(Response.Status.UNAUTHORIZED.getStatusCode(), "invalid_grant", "Account expired");
            context.failure(AuthenticationFlowError.INVALID_USER, response);
            return;
        } else {
            context.success();
        }
    } else {
        context.success();
    }
}