{{/* vim: set filetype=mustache: */}}

{{/* Doc : https://www.notion.so/saagie/JVM-Tuning-c26c06c1c5d946d2abd19c248d2539a0 */}}

{{/* Determine total memory in Mi available from limits.memory */}}
{{- define "common.java.resources.memory" -}}
{{- $resources := .resources -}}
{{- $lim := $resources.limits -}}
{{- if $lim.memory -}}
  {{- $ram := $lim.memory}}
  {{- $memVal := 0 -}}
  {{- if (hasSuffix "Gi" $ram) -}}
    {{- $tmpVal := (trimSuffix "Gi" $ram) -}}
    {{- $memVal = (mul (int $tmpVal) 1000) -}}
  {{- else if (hasSuffix "Mi" $ram) -}}
    {{- $memVal = (trimSuffix "Mi" $ram) -}}
  {{- end -}}
  {{- $memVal -}}
{{- end -}}
{{- end -}}

{{/* Compute percentage on memory, and floor value : must have a (dict "r" resource "p" percentage) in parameter */}}
{{- define "common.java.percentage" -}}
{{- $resource := .r | int -}}
{{- $percentage := (trimSuffix "%" .p) | int -}}
{{- (floor (div (mul $resource $percentage) 100)) | int -}}
{{- end -}}

{{/* Error/Guard on memory percentage : yaml keys must be known, and percentage sum must be lesser or equal 100% : must have a $jvm.memory in parameter */}}
{{- define "common.java.percentage.error" -}}
{{- $count := 0 -}}
{{- range $k, $v := . }}
  {{- if (or (eq $k "heap") (eq $k "metaspace") (eq $k "compressedClassSpaceSize") (eq $k "reservedCodeCacheSize")) -}}
    {{- $val := (trimSuffix "%" $v) | int -}}
    {{- $count = (add $count $val) -}}
  {{- else -}}
    {{- fail "The memory keys must be heap, metaspace, compressedClassSpaceSize or reservedCodeCaheSize" -}}
  {{- end -}}
{{- end -}}
{{- if (gt $count 100)}}
  {{- fail "The sum of the memory values must be less or equal to 100%" -}}
{{- end -}}
{{- end -}}

{{/* Create JVM options to apply in JAVA_TOOL_OPTIONS given context : can have a (list $root $context_for_resources) or just $root context in parameter */}}
{{- define "common.java.toolOptions" -}}
{{- $root := . -}}
{{- $valuesCtx := dict -}}
{{- if (kindIs "slice" . ) -}}
  {{- $root = first . -}}
  {{- $valuesCtx = last . -}}
{{- else -}}
  {{- $valuesCtx = .Values -}}
{{- end -}}
{{- $res := include "common.java.resources.memory" $valuesCtx | int -}}
{{- if (ge $res 128) -}}
  {{- $jvm := $valuesCtx.jvm | empty | ternary $root.Values.global.jvm $valuesCtx.jvm -}}
  {{- include "common.java.percentage.error" $jvm.memory -}}
  {{- if $jvm.memory.heap -}}
    {{- $heapPer := include "common.java.percentage" (dict "r" $res "p" $jvm.memory.heap) | int -}}
    {{- printf "-Xms%dm -Xmx%dm " $heapPer $heapPer -}}
  {{- end -}}
  {{- if $jvm.memory.metaspace -}}
    {{- $metaPer := include "common.java.percentage" (dict "r" $res "p" $jvm.memory.metaspace) | int -}}
    {{- printf "-XX:MetaspaceSize=%dm -XX:MaxMetaspaceSize=%dm " $metaPer $metaPer -}}
  {{- end -}}
  {{- if $jvm.memory.compressedClassSpaceSize -}}
    {{- $compCodePer := include "common.java.percentage" (dict "r" $res "p" $jvm.memory.compressedClassSpaceSize) | int -}}
    {{- printf "-XX:CompressedClassSpaceSize=%dm " $compCodePer -}}
  {{- end -}}
  {{- if and $jvm.memory.reservedCodeCacheSize -}}
    {{- $resCodePer := include "common.java.percentage" (dict "r" $res "p" $jvm.memory.reservedCodeCacheSize) | int -}}
    {{- $sizeCode := (floor (div (sub $resCodePer 5) 2)) | int -}}
    {{- printf "-XX:ReservedCodeCacheSize=%dm " $resCodePer -}}
    {{- printf "-XX:NonNMethodCodeHeapSize=%dm " 5 -}}
    {{- printf "-XX:ProfiledCodeHeapSize=%dm " $sizeCode -}}
    {{- printf "-XX:NonProfiledCodeHeapSize=%dm " $sizeCode -}}
    {{- printf "-XX:+TieredCompilation -XX:+SegmentedCodeCache" -}}
  {{- end -}}
{{- end -}}
{{- end -}}

{{- define "common.java.security" -}}
-Djava.security.egd=file:/dev/urandom
{{- end -}}

{{- define "common.java.options" -}}
{{include "common.java.security" .}} {{include "common.java.toolOptions" .}}
{{- end -}}
