{{/* vim: set filetype=mustache: */}}
{{/*
Prometheus - Override
*/}}
{{- define "prometheus.repositoryAndTag" -}}
{{- include "repositoryAndTag" . -}}
{{- end -}}
{{- define "prometheus.common.metaLabels" -}}
app: {{ template "prometheus.name" . }}
release: {{ .Release.Name }}
helm.sh/chart: {{ include "prometheus.chart" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
app.kubernetes.io/part-of: saagie-common
io.saagie/type: common
io.saagie/installationId: {{ .Release.Namespace }}
{{- end -}}

{{- define "prometheus.common.matchLabels" -}}
app.kubernetes.io/name: {{ template "prometheus.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end -}}

{{- define "prometheus.server.matchLabels" -}}
app.kubernetes.io/component: {{ .Values.server.name | quote }}
{{ include "prometheus.common.matchLabels" . }}
{{- end -}}

{{- define "prometheus.pushgateway.matchLabels" -}}
app.kubernetes.io/component: {{ .Values.pushgateway.name | quote }}
{{- end -}}

{{- define "saagie-common.prometheus-server.fullname" -}}
{{- dict "Values" (index .Values "monitoring-prometheus") "Release" .Release "Chart" (dict "Name" "monitoring-prometheus") | include "prometheus.server.fullname" -}}
{{- end -}}

{{- define "saagie-common.observability-prometheus-server.fullname" -}}
{{- dict "Values" (index .Values "observability-prometheus") "Release" .Release "Chart" (dict "Name" "observability-prometheus") | include "prometheus.server.fullname" -}}
{{- end -}}

{{- define "saagie-common.prometheus-server.labels" -}}
{{ dict "Values" (index .Values "monitoring-prometheus") "Release" .Release "Chart" (dict "Name" "monitoring-prometheus" "Version" "14.1.1") | include "prometheus.server.labels" }}
{{- end -}}

{{- define "saagie-common.observability-prometheus-server.labels" -}}
{{ dict "Values" (index .Values "observability-prometheus") "Release" .Release "Chart" (dict "Name" "observability-prometheus" "Version" "14.1.1") | include "prometheus.server.labels" }}
{{- end -}}

{{- define "saagie-common.prometheus-server.matchLabels" -}}
{{ dict "Values" (index .Values "monitoring-prometheus") "Release" .Release "Chart" (dict "Name" "monitoring-prometheus") | include "prometheus.server.matchLabels" }}
{{- end -}}

{{- define "saagie-common.observability-prometheus-server.matchLabels" -}}
{{ dict "Values" (index .Values "observability-prometheus") "Release" .Release "Chart" (dict "Name" "observability-prometheus") | include "prometheus.server.matchLabels" }}
{{- end -}}

{{- define "saagie-common.prometheus-server.ingress.auth.username" -}}
{{- $prometheus := index .Values "monitoring-prometheus" -}}
{{ required "The Saagie Monitoring Prometheus username is required" $prometheus.server.ingress.auth.username }}
{{- end -}}
{{- define "saagie-common.prometheus-server.ingress.auth.hashedPassword" -}}
{{- $prometheus := index .Values "monitoring-prometheus" -}}
{{ required "The Saagie Monitoring Prometheus hashedPassword is required" $prometheus.server.ingress.auth.hashedPassword }}
{{- end -}}
{{- define "saagie-common.prometheus-server.ingress.auth" -}}
{{ (printf "%s:%s" (include "saagie-common.prometheus-server.ingress.auth.username" .) (include "saagie-common.prometheus-server.ingress.auth.hashedPassword" .)) | b64enc }}
{{- end -}}

{{- define "saagie-common.prometheus.annotations" -}}
monitoring.saagie.io/scrape: {{ .scrape | default "true" | quote }}
{{- if .scheme }}
monitoring.saagie.io/scheme: {{ .scheme | quote }}
{{- end }}
{{- if .path }}
monitoring.saagie.io/path: {{ .path | quote }}
{{- end }}
{{- if .port }}
monitoring.saagie.io/port: {{ .port | quote }}
{{- end }}
{{- if .container }}
monitoring.saagie.io/container: {{ .container | quote }}
{{- end }}
{{- end -}}

{{- define "saagie-common.prometheus.annotations.jmx" -}}
{{ dict "port" "8031" | merge . | include "saagie-common.prometheus.annotations" }}
{{- end -}}
