{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "customer.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "customer.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "customer.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{- define "customer.labels.base" -}}
app: {{ include "customer.name" .context }}
chart: {{ include "customer.chart" .context }}
release: {{ .context.Release.Name }}
heritage: {{ .context.Release.Service }}
helm.sh/chart: {{ include "customer.chart" .context }}
io.saagie/installationId: {{ .context.Release.Namespace }}
{{ include "customer.selectorLabels.base" . }}
{{- if .context.Chart.AppVersion }}
app.kubernetes.io/version: {{ .context.Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .context.Release.Service }}
app.kubernetes.io/part-of: saagie-customer
{{- end -}}

{{- define "customer.labels" -}}
{{ dict "context" . | include "customer.labels.base" }}
{{- end -}}

{{- define "customer.labels.changelogs-post" -}}
{{ dict "component" "changelogs-post" "context" . | include "customer.labels.base" }}
{{- end -}}

{{- define "customer.labels.changelogs-pre" -}}
{{ dict "component" "changelogs-pre" "context" . | include "customer.labels.base" }}
{{- end -}}

{{- define "customer.labels.init" -}}
{{ dict "component" "init" "context" . | include "customer.labels.base" }}
{{- end -}}

{{- define "customer.labels.delete-appstore-data" -}}
{{ dict "component" "delete-appstore-data" "context" . | include "customer.labels.base" }}
{{- end -}}

{{- define "customer.selectorLabels.base" -}}
app.kubernetes.io/name: {{ include "customer.name" .context }}
app.kubernetes.io/instance: {{ .context.Release.Name }}
{{- if .component }}
app.kubernetes.io/component: {{ .component }}
{{- end }}
{{- end -}}

{{- define "instanceToJson" -}}
{{- if . }}
{{- printf "[" -}}
{{- range $index, $instance := . -}}
{{- if $index -}}
{{- printf "," -}}
{{- end -}}
{{- printf "{\"host\":%q,\"ip\":%q,\"port\":\"%d\"}" $instance.host $instance.ip (int64 $instance.port) -}}
{{- end -}}
{{- printf "]" -}}
{{- end -}}
{{- end -}}

{{- define "internalExternaltoJson" -}}
{{- if . }}
{{- printf "[" -}}
{{- range $index, $internal := . -}}
{{- if $index -}}
{{- printf "," -}}
{{- end -}}
{{- printf "{\"name\":\"%s\"" $internal.name -}}
{{- if $internal.instance -}}
{{- printf ",\"instance\":" -}}
{{- template "instanceToJson" $internal.instance -}}
{{- end -}}
{{- if $internal.url -}}
{{- printf ",\"url\":\"%s\"" $internal.url -}}
{{- end -}}
{{- $linkValue:= $internal.link -}}
{{- if ne (toString $linkValue) "<nil>" -}}
{{- printf ",\"link\":%t" $linkValue -}}
{{- end -}}
{{- printf "}" -}}
{{- end -}}
{{- printf "]" -}}
{{- end -}}
{{- end -}}

{{- define "readOnly" -}}
{{ (eq "ldap" (index .Values.global "security-root" "provider")) }}
{{- end }}

{{- define "mongodb.variables" -}}
SAAGIE_CUSTOMER_NAME: {{ .Values.global.customer.name | quote }}
SAAGIE_MONGODB_GRANTS:
- user: security
  databasePrefix: security-persistence-adapter
- user: auth
  databasePrefix: saagie
- user: authentication
  databasePrefix: authentication
- user: technologymanager
  databasePrefix: technology
SAAGIE_M2M_USER: {{ .Values.global.securityAccess.m2mUser | lower | quote }}
SAAGIE_PROTECTED_USERS: {{ .Values.global.securityAccess.protectedUsers | default (list) | mustToJson }}
SAAGIE_SECURITY_PROVIDER: {{ index .Values.global "security-root" "provider" | quote }}
{{- if (ne "ldap" (index .Values.global "security-root" "provider")) }}
SAAGIE_SECURITY_SUPER_ADMIN_GROUP: {{ .Values.global.securityAccess.superAdminGroup | lower | quote }}
{{- end }}
SAAGIE_ADMIN_GROUP: {{ .Values.global.securityAccess.adminGroup | lower | quote }}
SAAGIE_PROTECTED_GROUPS: {{ .Values.global.securityAccess.protectedGroups | default (list) | mustToJson }}
{{- end }}

{{- define "repositoryAndTagForK8sVersion" -}}
{{- $image := first . -}}
{{- $root := last . -}}
{{- $k8sVersion := printf "%s%s" $root.Capabilities.KubeVersion.Major (trimSuffix "+" $root.Capabilities.KubeVersion.Minor) -}}

{{- $errorMissingImage := printf "Template error : no thirdparty image with name %s has been provided in Values .global.thirdPartyImages.k8sVersionDependent" $image -}}
{{- $errorMissingVersion := printf "No %s image version has been defined for your K8S cluster version (%s)" $image $k8sVersion -}}
{{- $images := required $errorMissingImage (first (pluck $image $root.Values.global.thirdPartyImages.k8sVersionDependent)) -}}
{{- $version := required $errorMissingVersion (first (pluck $k8sVersion $images)) -}}
{{- with $version -}}
    {{- if $root.Values.global.registry -}}
    {{- printf "%s/%s:%s" $root.Values.global.registry .repository .tag -}}
    {{ else }}
    {{- printf "%s/%s:%s" .registry .repository .tag -}}
    {{- end -}}
{{- end -}}
{{- end -}}

{{- define "saagie-customer.technology-manager.host" -}}
{{ index .Values "technology-manager" "host" }}
{{- end -}}
{{- define "saagie-customer.technology-manager.port" -}}
{{ index .Values "technology-manager" "port" }}
{{- end -}}
{{- define "saagie-customer.technology-manager.url" -}}
http://{{ include "saagie-customer.technology-manager.host" . }}:{{ include "saagie-customer.technology-manager.port" . }}
{{- end -}}

{{- define "saagie-customer.projectsAndJobs.host" -}}
{{ .Values.projectsAndJobs.host }}
{{- end -}}
{{- define "saagie-customer.projectsAndJobs.port" -}}
{{ .Values.projectsAndJobs.port }}
{{- end -}}
{{- define "saagie-customer.projectsAndJobs.url" -}}
http://{{ include "saagie-customer.projectsAndJobs.host" . }}:{{ include "saagie-customer.projectsAndJobs.port" . }}
{{- end -}}

{{- define "saagie-customer.settings.host" -}}
{{ .Values.settings.host }}
{{- end -}}
{{- define "saagie-customer.settings.port" -}}
{{ .Values.settings.port }}
{{- end -}}
{{- define "saagie-customer.settings.url" -}}
http://{{ include "saagie-customer.settings.host" . }}:{{ include "saagie-customer.settings.port" . }}
{{- end -}}

{{- define "saagie-customer.mongodb.url" -}}
mongodb://root:$(MONGO_ROOT_PWD)@{{ .Values.mongodb.service.name }}:{{ .Values.mongodb.service.port }}/admin
{{- end -}}
