 {{/* vim: set filetype=mustache: */}}


{{- define "saagie-platform.truncated.name" -}}
{{- $context := index . 0 -}}
{{- $suffix := index . 1 -}}
{{- $customerName := trunc 30 $context.Values.global.customer.name }}
{{- $platformId := toString $context.id | trunc 10 }}
{{- printf "%s-pf%s-%s" $customerName $platformId $suffix | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{- define "saagie-platform.configmap.mongo" -}}
{{ tuple . "mongo" | include "saagie-platform.truncated.name"   }}
{{- end -}}
{{- define "saagie-platform.configmap.projects" -}}
{{ tuple . "projects" | include "saagie-platform.truncated.name"   }}
{{- end -}}
{{- define "saagie-platform.job.init-platform" -}}
{{ tuple . "init-platform" | include "saagie-platform.truncated.name"   }}
{{- end -}}

{{/*
Expand the name of the chart.
*/}}
{{- define "saagie-platform.name" -}}
saagie-platform
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "saagie-platform.fullname" -}}
{{- $customerName := trunc 45 .Values.global.customer.name }}
{{- $platformId := toString .id | trunc 15 }}
{{- printf "%s-pf%s" $customerName $platformId | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "saagie-platform.chart" -}}
{{- printf "%s-%s" "saagie-platform" .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{- define "saagie-platform.labels.base" -}}
app: {{ include (printf "%s.name" .prefix) .context }}
chart: {{ include "saagie-platform.chart" .context }}
release: {{ .context.Release.Name }}
heritage: {{ .context.Release.Service }}
helm.sh/chart: {{ include "saagie-platform.chart" .context }}
io.saagie/customer: {{ .context.Values.global.customer.name }}
io.saagie/platform-id: "{{ .context.id }}"
io.saagie/installationId: {{ .context.Release.Namespace }}
{{- if .component }}
{{ include (printf "%s.selectorLabels.%s" .prefix .component) .context }}
{{- else }}
{{ include (printf "%s.selectorLabels" .prefix) .context }}
{{- end }}
{{- if .context.Chart.AppVersion }}
app.kubernetes.io/version: {{ .context.Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .context.Release.Service }}
app.kubernetes.io/part-of: saagie-platform-instance
{{- end -}}

{{- define "saagie-platform.selectorLabels.base" -}}
app.kubernetes.io/name: {{ include (printf "%s.name" .prefix) .context }}
app.kubernetes.io/instance: "saagie-platform"
{{- if .component }}
app.kubernetes.io/component: {{ .component }}
{{- end }}
{{- end -}}

{{/*
Common labels
*/}}
{{- define "saagie-platform.labels" -}}
{{ dict "prefix" "saagie-platform" "context" . | include "saagie-platform.labels.base" }}
{{- end -}}

{{- define "saagie-platform.selectorLabels" -}}
{{ dict "prefix" "saagie-platform" "context" . | include "saagie-platform.selectorLabels.base" }}
{{- end -}}

{{- define "saagie-platform.labels.changelogs-post" -}}
{{ dict "prefix" "saagie-platform.changelogs-post" "context" . | include "saagie-platform.labels.base" }}
{{- end -}}

{{- define "saagie-platform.changelogs-post.selectorLabels" -}}
{{ dict "prefix" "saagie-platform.changelogs-pre" "context" . | include "saagie-platform.selectorLabels.base" }}
{{- end -}}

{{- define "saagie-platform.changelogs-post.name" -}}
{{- include "saagie-platform.name" . -}}
{{- end -}}

{{- define "saagie-platform.labels.changelogs-pre" -}}
{{ dict "prefix" "saagie-platform.changelogs-pre" "context" . | include "saagie-platform.labels.base" }}
{{- end -}}

{{- define "saagie-platform.changelogs-pre.selectorLabels" -}}
{{ dict "prefix" "saagie-platform.changelogs-pre" "context" . | include "saagie-platform.selectorLabels.base" }}
{{- end -}}

{{- define "saagie-platform.changelogs-pre.name" -}}
{{- include "saagie-platform.name" . -}}
{{- end -}}

{{- define "saagie-platform.labels.init" -}}
{{ dict "prefix" "saagie-platform.init" "context" . | include "saagie-platform.labels.base" }}
{{- end -}}

{{- define "saagie-platform.init.name" -}}
{{- include "saagie-platform.name" . -}}
{{- end -}}

{{- define "saagie-platform.init.selectorLabels" -}}
{{ dict "prefix" "saagie-platform.init" "context" . | include "saagie-platform.selectorLabels.base" }}
{{- end -}}

{{- define "saagie-platform.minio.name" -}}
{{- "minio" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{- define "saagie-platform.minio.fullname" -}}
{{- printf "%s-%s" "saagie-platform" (include "saagie-platform.minio.name" .) | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{- define "saagie-platform.minio.labels.base" -}}
{{ mustMerge (dict "prefix" "saagie-platform.minio") . | include "saagie-platform.labels.base" }}
{{- end -}}
{{- define "saagie-platform.minio.labels" -}}
{{ dict "component" "" "context" . | include "saagie-platform.minio.labels.base" }}
{{- end -}}

{{- define "saagie-platform.minio.selectorLabels.base" -}}
{{ mustMerge (dict "prefix" "saagie-platform.minio") . | include "saagie-platform.selectorLabels.base" }}
{{- end -}}
{{- define "saagie-platform.minio.selectorLabels" -}}
{{ dict "component" "" "context" . | include "saagie-platform.minio.selectorLabels.base" }}
{{- end -}}

{{- define "saagie-platform.minio.server.name" -}}
{{- include "saagie-platform.name" . -}}
{{- end -}}
{{- define "saagie-platform.minio.labels.server" -}}
{{ dict "component" "server" "context" . | include "saagie-platform.minio.labels.base" }}
{{- end -}}
{{- define "saagie-platform.minio.selectorLabels.server" -}}
{{ dict "component" "server" "context" . | include "saagie-platform.minio.selectorLabels.base" }}
{{- end -}}


{{- define "saagie-platform.minio.labels.make-bucket" -}}
{{ dict "component" "make-bucket" "context" . | include "saagie-platform.minio.labels.base" }}
{{- end -}}
{{- define "saagie-platform.minio.selectorLabels.make-bucket" -}}
{{ dict "component" "make-bucket" "context" . | include "saagie-platform.minio.selectorLabels.base" }}
{{- end -}}


{{- define "saagie-platform.mongodb.url" -}}
mongodb://root:$(MONGO_ROOT_PWD)@{{ .Values.mongodb.service.name }}:{{ .Values.mongodb.service.port }}/admin
{{- end -}}

{{- define "saagie-platform.minio.platform.defaultBucket.name" -}}
storage
{{- end -}}

{{- define "saagie-platform.minio.platform.defaultBucket.policy" -}}
none
{{- end -}}

{{- define "saagie-platform.minio.platform.defaultBucket.purge" -}}
false
{{- end -}}

{{- define "saagie-platform.minio.platform.defaultBucket.secretName" -}}
minio-read
{{- end -}}

{{- define "saagie-platform.minio.service.name" -}}
minio
{{- end -}}

{{- define "saagie-platform.minio.service.port" -}}
9000
{{- end -}}

{{- define "saagie-platform.minio.service.type" -}}
ClusterIP
{{- end -}}

{{- define "saagie-platform.minio.pvcName" -}}
minio
{{- end -}}

{{- define "saagie-platform.minio.secretName" -}}
minio
{{- end -}}


{{- define "saagie-platform.minio.resources" -}}
resources:
  requests:
    cpu: 10m
    memory: 128Mi
limits:
  cpu: 500m
  memory: 512Mi
{{- end -}}

{{- define "saagie-platform.minio.configPath" -}}
/root/.minio/
{{- end -}}

{{- define "saagie-platform.minio.mountPath" -}}
/storage
{{- end -}}