apiVersion: v1
kind: PersistentVolumeClaim
metadata:
  name: checker-volume-common
  namespace: ${namespace}
  labels:
    app.kubernetes.io/part-of: saagie-configurator
    app.kubernetes.io/instance: saagie-checker
    app.kubernetes.io/name: checker-volume
    app.kubernetes.io/component: common
    io.saagie/installationId: {installationId}
spec:
  accessModes:
    - ReadWriteOnce
  resources:
    requests:
      storage: 5Mi
  storageClassName: common-storageclass
---
apiVersion: v1
kind: PersistentVolumeClaim
metadata:
  name: checker-volume-customer
  namespace: {namespace}
  labels:
    app.kubernetes.io/part-of: saagie-configurator
    app.kubernetes.io/instance: saagie-checker
    app.kubernetes.io/name: checker-volume
    app.kubernetes.io/component: customer
    io.saagie/installationId: {installationId}
spec:
  accessModes:
    - ReadWriteOnce
  resources:
    requests:
      storage: 5Mi
  storageClassName: {customer}-storageclass
---
apiVersion: batch/v1
kind: Job
metadata:
  name: checker-volume
  namespace: {namespace}
spec:
  template:
    metadata:
      labels:
        app.kubernetes.io/part-of: saagie-configurator
        app.kubernetes.io/instance: saagie-checker
        app.kubernetes.io/name: checker-volume
        io.saagie/installationId: {installationId}
    spec:
      securityContext:
        runAsUser: 1200
        runAsGroup: 1200
        fsGroup: 1200
      volumes:
        - name: checker-volume-common
          persistentVolumeClaim:
            claimName: checker-volume-common
        - name: checker-volume-customer
          persistentVolumeClaim:
            claimName: checker-volume-customer
        - name: checker-volume
          configMap:
            name: checker-config-map
      containers:
        - name: checker-volume
          image: {image}
          imagePullPolicy: Always
          command: {command}
          volumeMounts:
            - mountPath: "/data/common"
              name: checker-volume-common
            - mountPath: "/data/customer"
              name: checker-volume-customer
            - mountPath: /config
              name: checker-volume
      restartPolicy: Never
  backoffLimit: 4
